| Title: | Estimation of Lifetime Attributable Risk of Cancer from Radiation Exposure |
|---|---|
| Description: | Compute lifetime attributable risk of radiation-induced cancer reveals that it can be helpful with enhancement of the flexibility in research with fast calculation and various options. Important reference papers include Berrington de Gonzalez et al. (2012) <doi:10.1088/0952-4746/32/3/205>, National Research Council (2006, ISBN:978-0-309-09156-5). |
| Authors: | Juhee Lee [aut, cre], Young-Min Kim [aut], YeongWoo Park [aut], Eunjin Jang [aut], Jinkyung Yoo [aut], Songwon Seo [ctb], Eun-Shil Cha [ctb], Won-Jin Lee [ctb] |
| Maintainer: | Juhee Lee <[email protected]> |
| License: | LGPL-3 |
| Version: | 1.0.0 |
| Built: | 2026-05-21 10:26:48 UTC |
| Source: | https://github.com/cran/LARisk |
A dataset containing the crude incidence rate of death by age, cancer site and gender.
incid2010incid2010
A data frame with 1919 rows and 4 variables:
Sitecancer site
Ageage
Rate_mcrude incidence rate for male
Rate_fcrude incidence rate for female
KOSIS(Ministry of Health and Welfare, Cancer Registration Statistics) https://kosis.kr/
A dataset containing the crude incidence rate of death by age, cancer site and gender.
incid2018incid2018
A data frame with 1919 rows and 4 variables:
Sitecancer site
Ageage
Rate_mcrude incidence rate for male
Rate_fcrude incidence rate for female
KOSIS(Ministry of Health and Welfare, Cancer Registration Statistics) https://kosis.kr/
LAR is used to estimate lifetime attributable radiation-related cancer risk for data with one person.
LAR( data, basedata, sim = 300, seed = 99, current = as.numeric(substr(Sys.Date(), 1, 4)), ci = 0.9, weight = NULL, DDREF = TRUE, basepy = 1e+05 )LAR( data, basedata, sim = 300, seed = 99, current = as.numeric(substr(Sys.Date(), 1, 4)), ci = 0.9, weight = NULL, DDREF = TRUE, basepy = 1e+05 )
data |
data frame containing demographic information and exposure information. See 'Details'. |
basedata |
a list of the data of lifetime table and incidence rate table. The first element is lifetime table and the second is incidence rate table. |
sim |
number of iteration of simulation. |
seed |
a random seed number. |
current |
a current year. default is year of the system time. |
ci |
confidence level of the confidence interval. |
weight |
a list containing the value between 0 and 1 which is a weight on ERR model. See 'Details'. |
DDREF |
logical. Whether to apply the dose and dose-rate effectiveness factor. |
basepy |
number of base person-years |
The maximum age in LAR is set as 100. If the data contains
birth which makes attained age (=current - birth)
exceed 100, the result has no useful value.
data should include information which includes gender, year of birth,
year of exposure, sites where exposed, exposure rate, distribution of dose and
dose parameters of exosed radiation. The name of each variables must be
sex, birth, exposure, site, exposure_rate,
dosedist, dose1, dose2, dose3.
For some variables, there is a fixed format. sex can have the component 'male' or 'female'.
site can have the component 'stomach', 'colon', 'liver', 'lung', 'breast', 'ovary', 'uterus', 'prostate', 'bladder', 'brain/cns',
'thyroid', 'remainder', 'oral', 'oesophagus', 'rectum', 'gallbladder', 'pancreas', 'kidney', 'leukemia'.
exposure_rate can have the component 'acute' or 'chronic'.
dosedist can have the component 'fixedvalue', 'lognormal', 'normal', 'triangular', 'logtriangular', 'uniform', 'loguniform'.
dose1, dose2, dose3 are parameters of dose distribution. The parameters for each distribution are that:
dose value (dose1)
median (dose1), geometric standard deviation (dose2)
mean (dose1), standard deviation (dose2)
minimum (dose1), mode (dose2), maximum (dose3)
minimum (dose1), maximum (dose2)
weight
LAR returns an object of "LAR" class.
An object of class "LAR" is a list containing the following components:
LARLifetime attributable risk (LAR) from the time of exposure to the end of the expected lifetime.
F_LARFuture attributable risk from current to the expected lifetime.
LBRLifetime baseline risk.
BFRBaseline future risk.
LFRLifetime fractional risk.
TFRTotal future risk.
currentCurrent year.
ciConfidence level.
pinfoInformation of the person.
Berrington de Gonzalez, A., Iulian Apostoaei, A., Veiga, L., Rajaraman, P., Thomas, B., Owen Hoffman, F., Gilbert, E. and Land, C. (2012). RadRAT: a radiation risk assessment tool for lifetime cancer risk projection. Journal of Radiological Protection, 32(3), pp.205-222.
National Research Council (NRC) and Committee to Assess Health Risks from Exposure to Low Levels of Ionizing Radiation (2005) Health Risks from Exposure to Low Levels of Ionizing Radiation: BEIR VII Phase 2 (Washington, DC: National Academy of Sciences)
## example with lifetime and incidence rate table in 2010 Korea. organ2 <- split(organ, organ$ID)[[1]] ## data of one person. ## defualt lar1 <- LAR(organ2, basedata = list(life2010, incid2010)) summary(lar1) ## change the weight for ERR and EAR models weight_list <- list("rectum" = 0.5) lar2 <- LAR(organ2, basedata = list(life2010, incid2010), weight = weight_list) summary(lar2) ## change the DDREF option (DDREF=FALSE) lar3 <- LAR(organ2, basedata = list(life2010, incid2010), DDREF = FALSE) summary(lar3)## example with lifetime and incidence rate table in 2010 Korea. organ2 <- split(organ, organ$ID)[[1]] ## data of one person. ## defualt lar1 <- LAR(organ2, basedata = list(life2010, incid2010)) summary(lar1) ## change the weight for ERR and EAR models weight_list <- list("rectum" = 0.5) lar2 <- LAR(organ2, basedata = list(life2010, incid2010), weight = weight_list) summary(lar2) ## change the DDREF option (DDREF=FALSE) lar3 <- LAR(organ2, basedata = list(life2010, incid2010), DDREF = FALSE) summary(lar3)
LAR_batch is used to estimate lifetime attributable radiation-related cancer risk for data with several people.
LAR_batch( data, pid, basedata, sim = 300, seed = 99, current = as.numeric(substr(Sys.Date(), 1, 4)), ci = 0.9, weight = NULL, DDREF = TRUE, basepy = 1e+05 )LAR_batch( data, pid, basedata, sim = 300, seed = 99, current = as.numeric(substr(Sys.Date(), 1, 4)), ci = 0.9, weight = NULL, DDREF = TRUE, basepy = 1e+05 )
data |
data frame containing demographic information and exposure information. See 'Details'. |
pid |
a vector which distinguish each person. |
basedata |
a list of the data of lifetime table and incidence rate table. The first element is lifetime table and the second is incidence rate table. |
sim |
number of iteration of simulation. |
seed |
a random seed number. |
current |
a current year. default is year of the system time. |
ci |
confidence level of the confidence interval. |
weight |
a list containing the value between 0 and 1 which is a weight on ERR model. See 'Details'. |
DDREF |
logical. Whether to apply the dose and dose-rate effectiveness factor. |
basepy |
number of base person-years |
LAR_batch returns an object of multiple classes
"LAR_batch", "LAR". An object of class LAR_batch is a
list of LAR class objects which names of elements are ID of each
person.
Berrington de Gonzalez, A., Iulian Apostoaei, A., Veiga, L., Rajaraman, P., Thomas, B., Owen Hoffman, F., Gilbert, E. and Land, C. (2012). RadRAT: a radiation risk assessment tool for lifetime cancer risk projection. Journal of Radiological Protection, 32(3), pp.205-222.
National Research Council (NRC) and Committee to Assess Health Risks from Exposure to Low Levels of Ionizing Radiation (2005) Health Risks from Exposure to Low Levels of Ionizing Radiation: BEIR VII Phase 2 (Washington, DC: National Academy of Sciences)
## example with lifetime and incidence rate table in 2010 Korea. lar1 <- LAR_batch(nuclear, pid=nuclear$ID, basedata = list(life2010, incid2010)) summary(lar1)## example with lifetime and incidence rate table in 2010 Korea. lar1 <- LAR_batch(nuclear, pid=nuclear$ID, basedata = list(life2010, incid2010)) summary(lar1)
LAR_group is used to estimate lifetime attributable radiation-related cancer risk by group.
LAR_group( data, pid, group, basedata, sim = 300, seed = 99, current = as.numeric(substr(Sys.Date(), 1, 4)), ci = 0.9, weight = NULL, DDREF = TRUE, basepy = 1e+05 )LAR_group( data, pid, group, basedata, sim = 300, seed = 99, current = as.numeric(substr(Sys.Date(), 1, 4)), ci = 0.9, weight = NULL, DDREF = TRUE, basepy = 1e+05 )
data |
data frame containing demographic information and exposure information. See 'Details'. |
pid |
a vector which distinguish each person. |
group |
a vector or list of vectors which distinguish each group. |
basedata |
a list of the data of lifetime table and incidence rate table. The first element is lifetime table and the second is incidence rate table. |
sim |
number of iteration of simulation. |
seed |
a random seed number. |
current |
a current year. default is year of the system time. |
ci |
confidence level of the confidence interval. |
weight |
a list containing the value between 0 and 1 which is a weight on ERR model. See 'Details'. |
DDREF |
logical. Whether to apply the dose and dose-rate effectiveness factor. |
basepy |
number of base person-years |
LAR_group returns an object of multiple classes
"LAR_group", "LAR". An object of class LAR_group is a
list of LAR class objects which names of elements are group of each
groups.
Berrington de Gonzalez, A., Iulian Apostoaei, A., Veiga, L., Rajaraman, P., Thomas, B., Owen Hoffman, F., Gilbert, E. and Land, C. (2012). RadRAT: a radiation risk assessment tool for lifetime cancer risk projection. Journal of Radiological Protection, 32(3), pp.205-222.
National Research Council (NRC) and Committee to Assess Health Risks from Exposure to Low Levels of Ionizing Radiation (2005) Health Risks from Exposure to Low Levels of Ionizing Radiation: BEIR VII Phase 2 (Washington, DC: National Academy of Sciences)
## example with lifetime and incidence rate table in 2010 Korea. lar1 <- LAR_group(nuclear, pid=nuclear$ID, group=nuclear$distance, basedata = list(life2010, incid2010)) summary(lar1) lar2 <- LAR_group(nuclear, pid=nuclear$ID, group=list(nuclear$sex, nuclear$distance), basedata = list(life2010, incid2010)) summary(lar2)## example with lifetime and incidence rate table in 2010 Korea. lar1 <- LAR_group(nuclear, pid=nuclear$ID, group=nuclear$distance, basedata = list(life2010, incid2010)) summary(lar1) lar2 <- LAR_group(nuclear, pid=nuclear$ID, group=list(nuclear$sex, nuclear$distance), basedata = list(life2010, incid2010)) summary(lar2)
A dataset containing the probability of death by age and gender.
life2010life2010
A data frame with 101 rows and 3 variables:
Ageage
Prob_d_mprobability of death for male
Prob_d_fprobability of death for female
KOSIS(Statistics Korea, Life Tables By Province) https://kosis.kr/
A dataset containing the probability of death by age and gender.
life2018life2018
A data frame with 101 rows and 3 variables:
Ageage
Prob_d_mprobability of death for male
Prob_d_fprobability of death for female
KOSIS(Statistics Korea, Life Tables By Province) https://kosis.kr/
nuclear is simulated dataset for acute exposure event. The scenario assumes that the people exposure the radiation at 2011.
nuclearnuclear
A data frame with 100 observation of 11 variables:
IDperson ID.
sexgender
birthbirth-year
exposureexposed year to radiation
siteorgan where exposed to radiation
exposure_rateexpsoure rate
dosedistdistribution of dose
dose1dose parameter
dose2dose parameter
dose3dose parameter
distancedistance from the hyper
organ is simulated dataset from the data of workers at interventional radiology departments.
organorgan
A data frame with 971 observation of 11 variables:
IDperson ID.
sexgender
birthbirth-year
exposureexposed year to radiation
siteorgan where exposed to radiation
exposure_rateexpsoure rate
dosedistdistribution of dose
dose1dose parameter
dose2dose parameter
dose3dose parameter
occupoccupation
Lee, W. J., Bang, Y. J., Cha, E. S., Kim, Y. M., & Cho, S. B. (2021). Lifetime cancer risks from occupational radiation exposure among workers at interventional radiology departments. International Archives of Occupational and Environmental Health, 94(1), 139-145.
print.LAR is the basic function for printing class "LAR".
## S3 method for class 'LAR' print(x, digits = 4, ...) ## S3 method for class 'LAR_batch' print(x, digits = 4, max.id = 50, ...) ## S3 method for class 'LAR_group' print(x, digits = 4, max.id = 50, ...)## S3 method for class 'LAR' print(x, digits = 4, ...) ## S3 method for class 'LAR_batch' print(x, digits = 4, max.id = 50, ...) ## S3 method for class 'LAR_group' print(x, digits = 4, max.id = 50, ...)
x |
'LAR', 'LAR_batch' or 'LAR_group' object. |
digits |
the number of decimal points to print. |
... |
further arguments to be passed from or to other methods. |
max.id |
the number of maximum of printing LAR results. |
summary.LAR is the function for printing class "LAR".
## S3 method for class 'LAR' summary(object, digits = 4, ...) ## S3 method for class 'LAR_batch' summary(object, digits = 4, max.id = 50, ...) ## S3 method for class 'LAR_group' summary(object, digits = 4, max.id = 50, ...)## S3 method for class 'LAR' summary(object, digits = 4, ...) ## S3 method for class 'LAR_batch' summary(object, digits = 4, max.id = 50, ...) ## S3 method for class 'LAR_group' summary(object, digits = 4, max.id = 50, ...)
object |
object of class 'LAR_batch' or LAR'. |
digits |
the number of decimal points to print. |
... |
further arguments to be passed from or to other methods. |
max.id |
the number of maximum of printing LAR results. |
Write 'LAR' object to CSV file
write_LAR(x, filename) ## S3 method for class 'LAR' write_LAR(x, filename) ## S3 method for class 'LAR_batch' write_LAR(x, filename) ## S3 method for class 'LAR_group' write_LAR(x, filename)write_LAR(x, filename) ## S3 method for class 'LAR' write_LAR(x, filename) ## S3 method for class 'LAR_batch' write_LAR(x, filename) ## S3 method for class 'LAR_group' write_LAR(x, filename)
x |
a 'LAR' object. |
filename |
a string naming the file to save (.csv file) |
LAR: write an 'LAR' class object
LAR_batch: write an 'LAR_batch' class object
LAR_group: write an 'LAR_group' class object